==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebGroupingDoneEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupingDoneEventArgsDetailDescriptionMetadata } from "./WebGroupingDoneEventArgsDetailDescriptionMetadata";
import { WebGroupingDoneEventArgsDescription } from "./WebGroupingDoneEventArgsDescription";
/**
 * @hidden
 */
export let WebGroupingDoneEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupingDoneEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupingDoneEventArgsDescriptionMetadata.a == null) {
                WebGroupingDoneEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupingDoneEventArgsDescriptionMetadata.c(WebGroupingDoneEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebGroupingDoneEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGroupingDoneEventArgsDescriptionMetadata.a);
            WebGroupingDoneEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupingDoneEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebGroupingDoneEventArgsDetail");
        }
        static d(a) {
            WebGroupingDoneEventArgsDescriptionMetadata.b(a);
            a.aa("WebGroupingDoneEventArgs", () => new WebGroupingDoneEventArgsDescription());
            a.z("WebGroupingDoneEventArgs", WebGroupingDoneEventArgsDescriptionMetadata.a);
        }
    }
    WebGroupingDoneEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGroupingDoneEventArgsDescriptionMetadata, 'WebGroupingDoneEventArgsDescriptionMetadata');
    WebGroupingDoneEventArgsDescriptionMetadata.a = null;
    return WebGroupingDoneEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGroupingDoneEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupingDoneEventArgsDetailDescriptionMetadata } from "./WebGroupingDoneEventArgsDetailDescriptionMetadata";
import { WebGroupingDoneEventArgsDescription } from "./WebGroupingDoneEventArgsDescription";
/**
 * @hidden
 */
export let WebGroupingDoneEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupingDoneEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupingDoneEventArgsDescriptionMetadata.a == null) {
                WebGroupingDoneEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupingDoneEventArgsDescriptionMetadata.c(WebGroupingDoneEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebGroupingDoneEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGroupingDoneEventArgsDescriptionMetadata.a);
            WebGroupingDoneEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupingDoneEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebGroupingDoneEventArgsDetail");
        }
        static d(a) {
            WebGroupingDoneEventArgsDescriptionMetadata.b(a);
            a.ac("WebGroupingDoneEventArgs", () => new WebGroupingDoneEventArgsDescription());
            a.ab("WebGroupingDoneEventArgs", WebGroupingDoneEventArgsDescriptionMetadata.a);
        }
    }
    WebGroupingDoneEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGroupingDoneEventArgsDescriptionMetadata, 'WebGroupingDoneEventArgsDescriptionMetadata');
    WebGroupingDoneEventArgsDescriptionMetadata.a = null;
    return WebGroupingDoneEventArgsDescriptionMetadata;
})();
